
local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local inventory = include( "sim/inventory" )
local unitdefs = include( "sim/unitdefs" )
local mission_util = include( "sim/missions/mission_util" )
local abilityutil = include( "sim/abilities/abilityutil" )

---------------------------------------------------------------------------------------------
-- Local helpers

local INCIDENT_NAME = "Credit Safe"

local function isSafe( u )
	return u:getTraits().safeUnit and not u:getTraits().incident_installed
end

local function hook( script, sim )
	local safeUnit = simquery.findUnit( sim:getAllUnits(), isSafe )
	if safeUnit == nil then
		log:write( "alpha_safe : no valid safe" )
		return
	end
	log:write( "alpha_safe : unit [%d] at <%d, %d>", safeUnit:getID(), safeUnit:getLocation() )
	safeUnit:getTraits().incident_installed = true
	
	local option
	
	while option == nil do
		local _, triggerData = script:waitFor( mission_util.PC_LOOTED_SAFE_PRE( safeUnit:getID() ))
		local unit = triggerData.unit
		local pronoun = STRINGS.GENDER_CONTEXT[unit:getUnitData().gender].he
		
		local txt = string.format("Behind the safe contents, there appears to be a sizable stack of credits in this safe. However it's locked away behind a physical lock.\n\nIf %s has a gun %s could try shooting at the lock.",unit:getName(),pronoun)
		local options =
		{
			"Leave the safe for now.",
			"Just take the available money.",
		}
		
		local weapon = simquery.getEquippedGun(unit)
		local canUse, reason = false, STRINGS.UI.REASON.NO_GUN
		
		if weapon then
			local abilitydef = weapon:hasAbility( "shootSingle" )
			if abilitydef then
				canUse, reason = abilityutil.canConsumeAmmo( sim, weapon )
				
				if weapon:getTraits().usesCharges and weapon:getTraits().charges < 1 then
					canUse = false
					reason = STRINGS.UI.REASON.CHARGES
				end
				
				if (weapon:getTraits().baseDamage or 0) <= 0 or weapon:getTraits().canSleep then
					canUse = false
					reason = "Not lethal"
				end
			end
		end
		
		if canUse then
			table.insert(options,string.format("Try to get the credits by shooting the locks with \n<c:F4FF78>%s</c>",weapon:getName()))
		elseif not weapon then
			txt = string.format("%s\n\n<c:F4FF78>%s</c>",txt,reason)
		elseif reason then
			txt = string.format("%s\n\n<c:F4FF78>Can't use %s (%s)</c>",txt,weapon:getName(),reason)
		end
		
		option = mission_util.showDialog( sim, INCIDENT_NAME, txt, options )

		if option == 1 then
			option = nil
			triggerData.abort = true
		elseif canUse and option == 3 then
			inventory.useItem( sim, unit, weapon )
			mission_util.showGoodResult( sim, INCIDENT_NAME, string.format("%s shoots through the locks.", unit:getName()))

		-- credits raised from 250 to 400
			local credits = simquery.scaleCredits( sim, 400 )
			unit:getPlayerOwner():addCredits(credits)
			sim:dispatchEvent( "INC_EV_CREDITS_ACQUIRED", { unit = unit, credits = credits } )

			sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = unit } )	
			sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = weapon } )
		else
			option = nil
		end
	end
end

---------------------------------------------------------------------------------------------
-- Begin!

local incident = class()

function incident:init( scriptMgr, sim )
	self.scriptMgr = scriptMgr
	scriptMgr:addHook( INCIDENT_NAME, hook, false )
end

return incident