local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local mission_util = include( "sim/missions/mission_util" )

---------------------------------------------------------------------------------------------
-- Local helpers

local INCIDENT_NAME = "WIRE"

local function isConsolePred( u )
	return u:getTraits().mainframe_console and not u:getTraits().console_incident
end

local function hijackConsole( script, sim )
	local consoleUnit = simquery.findUnit( sim:getAllUnits(), isConsolePred )
	if consoleUnit == nil then
		log:write( "alpha_wire : no valid console" )
		return
	end

	local option = nil
	while option == nil do

	log:write( "alpha_wire : unit [%d] at <%d, %d>", consoleUnit:getID(), consoleUnit:getLocation() )
	consoleUnit:getTraits().console_incident = true
	local _, triggerData = script:waitFor( mission_util.PC_HIJACKED( consoleUnit:getID() ))
  	local unit = triggerData.sourceUnit

	
		local title = "Console"
		local txt = string.format( "Before breaking into the console, %s sees an old, frayed wire sneaking out from behind the console. It could have special access privileges.", unit:getName() )
		local options = { "Plug in \n<c:F4FF78>(TAKE 2 KO DAMAGE)</c>", "Ignore wire and just collect the PWR", "Leave the console for now",  }
		local close = {"Close"}
		local case = nil

		if unit:getUnitData().class == "Engineer" or unit:getUnitData().class == "Cyborg" or unit:getUnitData().agentID == 1001 then 
			case = 1
		elseif unit:getUnitData().class == "Sharpshooter" or unit:getUnitData().agentID == 1000 or unit:getUnitData().agentID == 1003 then
			case = 2
		elseif unit:getUnitData().class == "Stealth" or unit:getUnitData().class == "Disguise" or unit:getUnitData().agentID == 1002 then
			case = 3
		else 
			case = 1
		end

		--tooltip
		if case == 1 then 
			txt = string.format("%s\n\n<c:F4FF78>%s can locate all floor's safes</c>",txt,unit:getName())
		elseif case == 2 then
			txt = string.format("%s\n\n<c:F4FF78>%s can access security data.</c>",txt,unit:getName())
		elseif case == 3 then
			txt = string.format("%s\n\n<c:F4FF78>%s can find objective and exit point.</c>",txt,unit:getName())
		end

		local option = mission_util.showDialog( sim, title, txt, options )		
	
		if option == 1 then
			local currentPlayer = sim:getCurrentPlayer()

			if case == 1 then 
				mission_util.showDialog( sim, title, "The wire comes noisily alive, filling map with secret data about this floor's safes. (AGENT TAKES 2 KO DAMAGE)", close )
						
				local unitlist = {}		
				sim:forEachUnit(						
				function ( unit )
					if unit:getTraits().safeUnit == true then
						table.insert(unitlist,unit:getID())		
						currentPlayer:glimpseUnit( sim, unit:getID() )			
					end
				end)
				sim:dispatchEvent( simdefs.EV_UNIT_MAINFRAME_UPDATE, {units=unitlist,reveal = true} )

			 elseif case == 2 then 
				mission_util.showDialog( sim, title, "The wire comes noisily alive, revealing current locations security units on this floor. (AGENT TAKES 2 KO DAMAGE)", close )
					
				local unitlist = {}		
				sim:forEachUnit(						
				function ( unit )
					if unit:getTraits().isGuard == true or unit:getTraits().anchorShot or unit:getUnitData().rig == "soundbugrig" then
						table.insert(unitlist,unit:getID())		
						currentPlayer:glimpseUnit( sim, unit:getID() )			
					end
				end)	
				sim:dispatchEvent( simdefs.EV_UNIT_MAINFRAME_UPDATE, {units=unitlist,reveal = true} )

			elseif case == 3 then  
				mission_util.showDialog( sim, title, "The wire comes noisily alive, revealing locations of objective and exit point. (AGENT TAKES 2 KO DAMAGE)", close )
				
				local room = nil
				for i,roomCheck in ipairs(sim._rooms) do
					if roomCheck.tags.objective then
						room = roomCheck.roomIndex
					end
				end
				local exitroom = nil
				sim:forEachCell(function(cell)
					if cell.exitID then 
						exitroom = cell.procgenRoom.roomIndex
					end
				end)
		
	 			local cells = {}
					    sim:forEachCell(function(cell)
						if cell.procgenRoom.roomIndex == exitroom or cell.procgenRoom.roomIndex == room then
						    sim:getPC():glimpseCell( sim, cell )
						    table.insert( cells, cell.x )
						    table.insert( cells, cell.y )
						end
					    end)
				sim:dispatchEvent( sim:getDefs().EV_LOS_REFRESH, { player = sim:getCurrentPlayer(), cells = cells } )
			end

			unit:setKO( sim, 2 )	

			return true
		elseif option == 2 then
			return true 
		else
			option = nil
			triggerData.abort = true
		end
	
end
end

---------------------------------------------------------------------------------------------
-- Begin!

local incident = class()

function incident:init( scriptMgr, sim )
	self.scriptMgr = scriptMgr
	scriptMgr:addHook( INCIDENT_NAME, hijackConsole, false )
end

return incident
