local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local mission_util = include( "sim/missions/mission_util" )
local inventory = include( "sim/inventory" )
local weighted_list = include( "modules/weighted_list" )
local unitdefs = include("sim/unitdefs")
local simfactory = include( "sim/simfactory" )

---------------------------------------------------------------------------------------------
-- Local helpers

local function isConsolePred( u )
	return u:getTraits().mainframe_console and not u:getTraits().console_incident
end

local function isSafePred( u )
	return u:getTraits().safeUnit and not u:getTraits().incident_installed
end

local function hijackConsole( script, sim )


	local consoleUnit = simquery.findUnit( sim:getAllUnits(), isConsolePred )
	local safeUnit = simquery.findUnit( sim:getAllUnits(), isSafePred )

	if consoleUnit == nil or safeUnit == nil then
		log:write( "console_encrypted_data: no valid console and safe" )
		return
	end

	local x0, y0 = consoleUnit:getLocation()
	log:write( string.format("console_encrypted_data : units [%d] at <%d, %d>, [%d] at <%d, %d>", consoleUnit:getID(), x0, y0, safeUnit:getID(), safeUnit:getLocation()) )
	consoleUnit:getTraits().console_incident = true
	safeUnit:getTraits().incident_installed = true
	
	local itemList = {				--copied from EA simdefs.ITEMS_SPECIAL as it was here but with nerfs:
			{ "item_hologrenade" ,10},
			{ "item_stickycam" ,10},
			{ "item_lockdecoder",10},
			{ "item_defiblance",10},
			{ "augment_distributed_processing",10 },
			{ "augment_microslam_apparatus",10},
			{ "augment_carbon_myomer",10},
			{ "item_dartgun_dam", 10},		-- instead of { "item_bio_dartgun",10},
			{"item_light_pistol_KO",10},		-- instead of { "item_light_pistol_ammo",10},
			{ "vault_passcard",10},
		}

	local dropTable = weighted_list( itemList )
	local w = sim:nextRand( 1, dropTable:getTotalWeight() )
	local item = dropTable:getChoice( w )

	local option
	while option == nil do
		local _, triggerData = script:waitFor( mission_util.PC_HIJACKED( consoleUnit:getID() ))

		local unit = triggerData.sourceUnit
		local title = "Console"
		local txt = "Scanning the console, Incognita reports that she's found an intriguing file. It's encrypted, but it doesn't use an algorithm approved by the corporation. Incognita could focus her PWR on cracking the file to find out what's in there."
		local options = 
		{ 
			"Leave the console for now.", 	
			"Ignore it, it's not worth the PWR.", 
			"Tell Incognita to decrypt the file. <c:F4FF78>(cost: console PWR)</c>",	
		}

		option = mission_util.showDialog( sim, title, txt, options, { enemyProfile = {build="portraits/incognita_face",anim="portraits/incognita_face"} } )

		if option == 2 then

		elseif option == 3 then
			local currentPlayer = sim:getCurrentPlayer()

			mission_util.showGoodResult( sim, title, string.format("The encryption turns out to be flimsy, and it doesn't take long for Incognita to crack it. Inside the file, she finds the location of a secret cache hidden in a safe on this floor. An employee must have hidden it, probably as a fallback in case they crossed the wrong executive.") )
			
			consoleUnit:getTraits().hijacked = true
			consoleUnit:setPlayerOwner(currentPlayer)			
			consoleUnit:getTraits().cpus = 0
			
			sim:dispatchEvent( simdefs.EV_CAM_PAN, { safeUnit:getLocation() } )

			local t = inventory.giftUnit( sim, safeUnit, item, false )

			currentPlayer:glimpseUnit( sim, safeUnit:getID() )
			if safeUnit:getPlayerOwner() == currentPlayer then
			--	sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = safeUnit ,reveal = true} )	
			end

			sim:dispatchEvent( simdefs.EV_UNIT_MAINFRAME_UPDATE, {units={safeUnit:getID()},reveal = true} )

			sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = unit } )
			sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = consoleUnit } )
			triggerData.abort = true 
			--return false  
		elseif option == 1 then
			triggerData.abort = true
			option = nil
		end
	end
end

---------------------------------------------------------------------------------------------
-- Begin!

local incident = class()

function incident:init( scriptMgr, sim )
	self.scriptMgr = scriptMgr
	scriptMgr:addHook( "ENCRYPTED_DATA", hijackConsole, false )
end

return incident
