local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local mission_util = include( "sim/missions/mission_util" )
local mainframe_abilities = include( "sim/abilities/mainframe_abilities" )
local abilitydefs = include( "sim/abilitydefs" )

---------------------------------------------------------------------------------------------
-- Local helpers

local function isConsolePred( u )
	return u:getTraits().mainframe_console and not u:getTraits().console_incident
end

local function hijackConsole( script, sim )
	local currentPlayer = sim:getPC()
	local consoleUnit = simquery.findUnit( sim:getAllUnits(), isConsolePred )

	local programs = {
		"wrench_2",
		"wrench_3",
		"wrench_4",
		"wrench_5",
		"wings",
		"shade",
		"pwr_manager_2",		
	}

	local mainframe_program
	while mainframe_program == nil and #programs > 0 do
		mainframe_program = table.remove(programs,sim:nextRand(1,#programs))
		if currentPlayer:hasMainframeAbility( mainframe_program ) then
			mainframe_program = nil
		end
	end
	
	if not mainframe_program then
		return
	end
	
	if consoleUnit == nil or #currentPlayer:getAbilities() >= simdefs.MAX_PROGRAMS or currentPlayer:hasMainframeAbility( mainframe_program )  then
		log:write( "console_incognita_program : no valid console" )
		return
	end

	log:write( "console_incognita_program : unit [%d] at <%d, %d>", consoleUnit:getID(), consoleUnit:getLocation() )
	consoleUnit:getTraits().console_incident = true

	local option = nil
	while option == nil do
		local _, triggerData = script:waitFor( mission_util.PC_HIJACKED( consoleUnit:getID() ))
		
	    local unit = triggerData.sourceUnit

		local title = "Console"	
		local txt = string.format( "As %s is about to begin a PWR transfer, Incognita pipes in with an alert. \n\n<c:FFFFFF>I've detected a module running in this console's memory. I can acquire it as an upgrade, but this will force me to reset my processes and lose our current stock of PWR.</>\n\n<c:F4FF78>PWR: %d</c>",unit:getName(),currentPlayer:getCpus() )	

		local options = 
		{ 
			"Wait with using this Console.", 
			"Ignore Incognita, and transfer the PWR",
			"Install and reset Incognita. <c:F4FF78>(cost: remaining PWR)</>",
		}
		
		local maxPrograms = simdefs.MAX_PROGRAMS  + (sim:getParams().agency.extraPrograms or 0)
		if #currentPlayer:getAbilities() >= maxPrograms then
			options[3] = nil
			txt = string.format("%s\n<c:F4FF78>%s</c>",txt,STRINGS.UI.TOOLTIP_PROGRAMS_FULL)
		end

		local option = mission_util.showDialog( sim, title, txt, options, { enemyProfile = {build="portraits/incognita_face",anim="portraits/incognita_face"} } )	    
   
		if option == 1 then
			option = nil
			triggerData.abort = true
		elseif option == 3 then
			mission_util.showGoodResult( sim, title, "Incognita copies the module down, and her signal goes dead as you wait for her to restart. Several heartbeats later, she reappears.\n\n<c:FFFFFF>Upgrade successful. The module has become a part of me. </>\n\n<c:F4FF78>PWR emptied</>", { enemyProfile = {build="portraits/incognita_face",anim="portraits/incognita_face"}} )

			consoleUnit:getTraits().hijacked = true
			consoleUnit:setPlayerOwner(currentPlayer)	
			consoleUnit:getTraits().cpus = 0	
		
			currentPlayer:addCPUs( -currentPlayer:getCpus() )

			sim:getStats():incStat( "programs_earned" )
		
			sim:dispatchEvent( simdefs.EV_PLAY_SOUND, "SpySociety/VoiceOver/Incognita/Pickups/NewProgram" )

			currentPlayer:addMainframeAbility( sim, mainframe_program )
			local mainframeDef = abilitydefs.lookupAbility(mainframe_program)
			local dialogParams =
			{
				STRINGS.PROGRAMS.INSTALLED,
				mainframeDef.name,
				string.format( STRINGS.PROGRAMS.INSTALLED_DESC, mainframeDef.desc),
				mainframeDef.icon_100,
				color = {r=1,g=0,b=0,a=1}
			}	
			sim:dispatchEvent( simdefs.EV_SHOW_DIALOG, { dialog = "programDialog", dialogParams = dialogParams } )
			
			sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = unit } )
			sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = consoleUnit } )
			triggerData.abort = true 
		end
	end
end

---------------------------------------------------------------------------------------------
-- Begin!

local incident = class()

function incident:init( scriptMgr, sim )
	self.scriptMgr = scriptMgr
	scriptMgr:addHook( "incognita_program", hijackConsole, false )
end

return incident
