local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local mission_util = include( "sim/missions/mission_util" )
local weighted_list = include( "modules/weighted_list" )
local simfactory = include( "sim/simfactory" )
local unitdefs = include( "sim/unitdefs" )

---------------------------------------------------------------------------------------------
-- Local helpers

local function isConsolePred( u )
	return u:getTraits().mainframe_console and not u:getTraits().console_incident
end

local function isNanofabPred( u )
	return u:getTraits().storeType=="standard"
end


local function spawnInterest(sim,unit)
	local x0, y0 = unit:getLocation()
    sim:getNPC():spawnInterest(x0, y0, simdefs.SENSE_RADIO, simdefs.REASON_CAMERA )
    sim:processReactions( )
end

local function hijackConsole( script, sim )
	local consoleUnit = simquery.findUnit( sim:getAllUnits(), isConsolePred )
	local nanofabUnit = simquery.findUnit( sim:getAllUnits(), isNanofabPred )
	
	if consoleUnit == nil or  nanofabUnit == nil then
		log:write( "console_nanofab_plan: no valid console" )
		return
	end

	local item = nil
	local itemList = simdefs.ITEMS_SPECIAL_DAY_1
	local itemList = {				--copied from EA simdefs.ITEMS_SPECIAL as it was there but with changes:
			{ "item_hologrenade" ,10},
			{ "item_stickycam" ,10},
			{ "item_lockdecoder",10},
			{ "item_defiblance",10},
			{ "augment_distributed_processing",10 },
			{ "augment_microslam_apparatus",10},
			{ "augment_carbon_myomer",10},
			{ "augment_net_downlink ",10},			-- added
			{ "augment_torque_injectors",10},		-- added
			{ "item_bio_dartgun",10},			
			{ "item_light_pistol_ammo",10},		
			{ "vault_passcard",10},
			{ "item_tazer_3",10}, 				-- added
			{ "item_wireless_scanner_1",10},		-- added
		}


	local dropTable = weighted_list( itemList )
	local w = sim:nextRand( 1, dropTable:getTotalWeight() )
	item = dropTable:getChoice( w )
	local itemData =  unitdefs.lookupTemplate( item )
	local newItem = simfactory.createUnit( itemData, sim )

	local x0, y0 = consoleUnit:getLocation()
	log:write( string.format("console_nanofab_plan : units [%d] at <%d, %d>, [%d] at <%d, %d>", consoleUnit:getID(), x0, y0, nanofabUnit:getID(), nanofabUnit:getLocation()) )
	consoleUnit:getTraits().console_incident = true

	local option = nil
    while option == nil do
		local _, triggerData = script:waitFor( mission_util.PC_HIJACKED( consoleUnit:getID() ))

	    local unit = triggerData.sourceUnit

		local hacking = unit:getSkillLevel( "hacking" )

		local title = "Console"
		local txt = string.format("A quick inspection reveals that this console is connected to the floor's Nanofabricator. It looks like someone was about to push an illicit new pattern to the Nanofab – but then they realized that the traffic is monitored, and that scared them off. Of course, %s might be able to keep security in the dark while the Nanofab is working.\n\n<c:F4FF78>%s's AP: %d\nHacking %d</c>", unit:getName(), unit:getName(), unit:getTraits().mp, hacking)
		local options = 
		{
			"Leave the console for now.",
			"Ignore the new pattern and just collect the PWR.", 		
			string.format("Hide the transmission and push the pattern\n<c:F4FF78>(HACKING cost: remaining AP)</>"), 
			"Push the pattern to the Nanofab, and deal with the consequences.",
		}
		local option = mission_util.showDialog( sim, title, txt, options )

		if option == 2 then

		elseif option == 3 then
			local currentPlayer = sim:getCurrentPlayer()		
			local rand  = sim:nextRand(1,10)

			if rand + hacking > 8 then
				mission_util.showGoodResult( sim, title, "Rerouting the data through several other terminals on the floor sufficently hides the signal.\n\n<c:F4FF78>(New pattern added to Nanofab)</>" )
                nanofabUnit:addItem( newItem ) 
			else 
				mission_util.showBadResult( sim, title, string.format("%s tries to disguise the request, but the sys admin on duty tries even harder to trace it. Before the Nanofab can start working, the sys admin has banned the pattern from the system – and traced %s back to this console.\n\n<c:F4FF78>(Location compromised)</>",unit:getName(),unit:getName() ) )
				spawnInterest(sim,unit)
			end		
			unit:getTraits().mp = 0	

		elseif option == 4 then
			mission_util.showGoodResult( sim, title, "The new pattern is pushed to the Nanofab's buffer. As you expected, the misuse of company resources does not go unnoticed: someone is coming to investigate.\n\n<c:F4FF78>(New pattern added to Nanofab)\n(Location compromised)</>" )
			spawnInterest(sim,unit)
            nanofabUnit:addItem( newItem )
		elseif option == 1 then
			triggerData.abort = true
	    end
	end
end

---------------------------------------------------------------------------------------------
-- Begin!

local incident = class()

function incident:init( scriptMgr, sim )
	self.scriptMgr = scriptMgr
	scriptMgr:addHook( "nanofab_plan", hijackConsole, false )
end

return incident
