local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local mission_util = include( "sim/missions/mission_util" )
local guarddefs = include("sim/unitdefs/guarddefs")

---------------------------------------------------------------------------------------------
-- Local helpers

local function isConsolePred( u )
	return u:getTraits().mainframe_console and not u:getTraits().console_incident
end

local function hijackConsole( script, sim )
	local consoleUnit = simquery.findUnit( sim:getAllUnits(), isConsolePred )
	if consoleUnit == nil  then
		log:write( "console_security_dispatch : no valid console" )
		return
	end

	log:write( "console_security_dispatch : unit [%d] at <%d, %d>", consoleUnit:getID(), consoleUnit:getLocation() )
	consoleUnit:getTraits().console_incident = true

	local _, triggerData = script:waitFor( mission_util.PC_HIJACKED( consoleUnit:getID() ))

    local unit = triggerData.sourceUnit
	local hacking = unit:getSkillLevel( "hacking" )
	local stealth = unit:getSkillLevel( "stealth" )

	local profileAnim="portraits/portrait_animation_template"
	local profileBuild="portraits/portrait_security_build"
	local wt = util.weighted_list( sim._patrolGuard )
	local choices = {}
	
	for i = 2, #wt, 2 do
		local template = guarddefs[wt[i]]
		if not template.traits.isDrone then
			table.insert(choices,template)
		end
	end
	
	if #choices > 0 then
		local template = choices[sim:nextRand(1,#choices)]
		if template.profile_anim then
			profileAnim = template.profile_anim							
		end
		if template.profile_build then
			profileBuild = template.profile_build							
		end
	end

	local title = "SECURITY DISPATCH"
	local txt = string.format( "After breaking into the console, %s notices a single line of blinking text.\n\n<c:F4FF78>THIS IS SECURITY. IDENTIFY YOURSELF.</>\n\n<c:F4FF78>%s's AP: %d\nHacking %d\nStealth %d</c>", unit:getName(), unit:getName(), unit:getTraits().mp, hacking, stealth )

	local options = 
	{ 
		"Attempt a bribe. <c:F4FF78>(STEALTH cost: 250 CREDITS)</>",
		string.format("Attempt to hack the system <c:F4FF78>(HACKING cost: remaining AP)</>"), 
		"Do nothing.",
	}
	
	local option = mission_util.showDialog( sim, title, txt, options, { enemyProfile = {build=profileBuild,anim=profileAnim, color={r=0,g=0,b=0}} } )

	if option == 1 then
		local currentPlayer = sim:getCurrentPlayer()
		local rand  = sim:nextRand(1,10)

		if rand + stealth > 6 then
			mission_util.showGoodResult( sim, title, "<c:F4FF78>Good doing business with you.</>\n\nThe message disappears quickly.\n\n<c:F4FF78>(Tracker decreased by 3)</>" )
			sim:trackerDecrement(3)
			currentPlayer:addCredits(-250)
		else 
			mission_util.showBadResult( sim, title, "<c:F4FF78>Thanks for your credits. I'm still calling it in.</>\n\nThe message disappears quickly and the screen flashes red.\n\n<c:F4FF78>(Tracker increased by 2)</>" )
			sim:trackerAdvance(2)
			currentPlayer:addCredits(-250)
		end

	elseif option == 2 then
		local currentPlayer = sim:getCurrentPlayer()
		local rand  = sim:nextRand(1,10)

		if rand + hacking > 8 then
			mission_util.showGoodResult( sim, title, "<c:F4FF78>You successfully hack the system, allowing you to show the security correct credentials.</>" )
		else 
			local trackerAdvance = sim:nextRand(1,3)
			mission_util.showBadResult( sim, title, string.format("<c:F4FF78>You botch the hack, and security calls it in.</>\n\nThe message disappears quickly and the screen flashes red.\n\n<c:F4FF78>(Tracker increased by %d)</>",trackerAdvance) )			
			sim:trackerAdvance(trackerAdvance)
		end
		unit:getTraits().mp = 0		

	elseif option == 3 then		
		mission_util.showBadResult( sim, title, string.format("<c:F4FF78>UNAUTHORIZED ACCESS DETECTED.</>\n\nThe message disappears quickly and the screen flashes red.\n\n<c:F4FF78>(Tracker increased by 2)</>" ) )
		sim:trackerAdvance(2)
	end
end

---------------------------------------------------------------------------------------------
-- Begin!

local incident = class()

function incident:init( scriptMgr, sim )
	self.scriptMgr = scriptMgr
	scriptMgr:addHook( "SECURITY DISPATCH", hijackConsole, false )
end

return incident
