local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local mission_util = include( "sim/missions/mission_util" )
local mainframe_abilities = include( "sim/abilities/mainframe_abilities" )
local abilitydefs = include( "sim/abilitydefs" )

---------------------------------------------------------------------------------------------
-- Local helpers

local function isConsolePred( u )
	return u:getTraits().mainframe_console and not u:getTraits().console_incident
end

local function hijackConsole( script, sim )
	local currentPlayer = sim:getCurrentPlayer()
	local consoleUnit = simquery.findUnit( sim:getAllUnits(), isConsolePred )

	if consoleUnit == nil then
		log:write( "console_sell_pwr : no valid console" )
		return
	end

	log:write( "console_sell_pwr : unit [%d] at <%d, %d>", consoleUnit:getID(), consoleUnit:getLocation() )
	consoleUnit:getTraits().console_incident = true


	local option = nil
	while option == nil do
		local _, triggerData = script:waitFor( mission_util.PC_HIJACKED( consoleUnit:getID() ))

	    local unit = triggerData.sourceUnit
	    local request = currentPlayer:getCpus()
	    local stealth = unit:getSkillLevel( "stealth" )
	    local cred = request * 50

		local num = math.floor(sim:nextRand()*4)+1

		if request > num then

			local title = "Console"	
			local txt = string.format( "%s gets a com signal while working the console.\n\n<c:ffffff>I'm not sure who you are, but thank god I found your signal..\n\nI'm in a bad situation. Please, sell me your PWR. I'll send you %d CREDITS.</>\n\n<c:F4FF78>PWR: %d\nCREDITS %d</c>",unit:getName(), cred, currentPlayer:getCpus(),currentPlayer:getCredits() )	

			local options = 
			{ 
				"Ignore the message.",			
				string.format("It's a deal.\n<c:F4FF78>(%d CREDITS for %d PWR)</>",cred, request),
			}

			local option = mission_util.showDialog( sim, title, txt, options, { enemyProfile = {build="portraits/courier_face",anim="portraits/courier_face", color={r=0,g=0,b=0} } } )	    
	   
			if option == 1 then
				mission_util.showNeutralResult( sim, title, "A second message arrives:\n\n<c:ffffff>PLEASE! I need that PWR RIGHT NOW!</>\n\nThere is no third message." , { enemyProfile = {build="portraits/courier_face",anim="portraits/courier_face", color={r=0,g=0,b=0} } } )	
			elseif option == 2 then
				mission_util.showGoodResult( sim, title, string.format("<c:ffffff>YES! You have no idea! You made the right choice, patching the credit over now.</>\n\n<c:F4FF78>(+%d CREDITS  -%d PWR)</>",cred,request) , { enemyProfile = {build="portraits/courier_face",anim="portraits/courier_face", color={r=0,g=0,b=0} } } )	
				currentPlayer:addCPUs( -request )
				currentPlayer:addCredits(cred)
			end
		else
			request = math.floor(sim:nextRand()*4)+4
  			cred = request * 50

			local title = "Console"	
			local txt = string.format( "%s gets a com signal while working the console.\n\n<c:ffffff>I'm not sure who you are, but I can see you're not corporate.\n\nYou're looking for PWR. I'll sell you some.\n\nHow about %d PWR for %d CREDIT.</>\n\n<c:F4FF78>PWR: %d\nCREDITS %d</c>",unit:getName(), request, cred , currentPlayer:getCpus(),currentPlayer:getCredits() )	

			local options = 
			{ 
				"Ignore the message.",			
				string.format("It's a deal. <c:F4FF78>(%d PWR for %d CREDITS)</>", request, cred),
			}

			local option = mission_util.showDialog( sim, title, txt, options , { enemyProfile = {build="portraits/courier_face",anim="portraits/courier_face", color={r=0,g=0,b=0} } } )	
	   
			if option == 1 then
				
			elseif option == 2 then
				if currentPlayer:getCredits() < cred then
					mission_util.showNeutralResult( sim, title, string.format("<c:ffffff>Really? don't even have that much?\n\nForget it. Too hot now anyway. I'm out.</>\n\n"), { enemyProfile = {build="portraits/courier_face",anim="portraits/courier_face", color={r=0,g=0,b=0} } } )	
				else
					mission_util.showGoodResult( sim, title, string.format("<c:ffffff>Alright, sending it to your feed now.\n\nThis never happend.</>\n\n<c:F4FF78>(+%d PWR  -%d CREDITS)</>",request,cred) , { enemyProfile = {build="portraits/courier_face",anim="portraits/courier_face", color={r=0,g=0,b=0} } } )	
					currentPlayer:addCPUs( request )
					currentPlayer:addCredits(-cred)
				end
			end

		end
	end
end

---------------------------------------------------------------------------------------------
-- Begin!

local incident = class()

function incident:init( scriptMgr, sim )
	self.scriptMgr = scriptMgr
	scriptMgr:addHook( "sell_pwr", hijackConsole, false )
end

return incident
