local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local mission_util = include( "sim/missions/mission_util" )
local guarddefs = include("sim/unitdefs/guarddefs")

---------------------------------------------------------------------------------------------
-- Local helpers

local function isConsolePred( u )
	return u:getTraits().mainframe_console and not u:getTraits().console_incident
end

local function shiftPatrols(sim)
	local idle = sim:getNPC():getIdleSituation()
	local guards = sim:getNPC():getUnits()

	for i,guard in ipairs(guards) do
       if guard:getBrain() and guard:getBrain():getSituation().ClassType == simdefs.SITUATION_IDLE then
		    idle:generatePatrolPath( guard )
            if guard:getTraits().patrolPath and #guard:getTraits().patrolPath > 1 then
			    local firstPoint = guard:getTraits().patrolPath[1]
			    guard:getBrain():getSenses():addInterest(firstPoint.x, firstPoint.y, simdefs.SENSE_RADIO, simdefs.REASON_PATROLCHANGED, guard)
		    end
        end
	end
end

local function hijackConsole( script, sim )
	local consoleUnit = simquery.findUnit( sim:getAllUnits(), isConsolePred )
	if consoleUnit == nil then
		log:write( "console_shift_change: no valid console" )
		return
	end

	log:write( "console_shift_change : unit [%d] at <%d, %d>", consoleUnit:getID(), consoleUnit:getLocation() )
	consoleUnit:getTraits().console_incident = true

	local option = nil
	while option == nil do

		local _, triggerData = script:waitFor( mission_util.PC_HIJACKED( consoleUnit:getID() ))

	    local unit = triggerData.sourceUnit

		local title = "Console"
		local pronoun = STRINGS.GENDER_CONTEXT[unit:getUnitData().gender].he

		local hacking = unit:getSkillLevel( "hacking" )
		
		local txt = string.format("It appears this terminal is patched into the guard coms. %s picks up some chatter..\n\nSecCom402:<c:ffffff> \"We just finished level 3 and need to tighten up the security a little bit.\"</>\n\nDivCom21:<c:ffffff> \"Roger that, please wait for new patrol notifications.\"</>",unit:getName(), pronoun, unit:getName(), unit:getTraits().mp, hacking )	
		local options = 
		{
			"Wait for a better opportunity",
			"Carry on as usual", 
			"Send the patrol change notification now"		
		}

		local profileAnim="portraits/portrait_animation_template"
		local profileBuild="portraits/portrait_security_build"
		local wt = util.weighted_list( sim._patrolGuard )	
		local choices = {}
		
		for i = 2, #wt, 2 do
			local template = guarddefs[wt[i]]
			if not template.traits.isDrone then
				table.insert(choices,template)
			end
		end
		
		if #choices > 0 then
			local template = choices[sim:nextRand(1,#choices)]
			if template.profile_anim then
				profileAnim = template.profile_anim							
			end
			if template.profile_build then
				profileBuild = template.profile_build							
			end
		end


		option = mission_util.showDialog( sim, title, txt, options, { enemyProfile = {build = profileBuild, anim = profileAnim, color={r=0,g=0,b=0}} } )
		
		if option == 1 then
			triggerData.abort = true
			option = nil
		elseif option == 2 then
		elseif option == 3 then
			mission_util.showNeutralResult( sim, title, string.format("The notification is sent out.\n\nSecCom402:<c:ffffff> \"Roger that Div Com. All units, switch to patrol Echo Alpha.\"</>\n\nDivCom21:<c:ffffff> \"Ah.. I didn't.. Nevermind. Carry on Section Commander.\"</></>\n\n<c:F4FF78>(Guard patrols shifted) </>"), { enemyProfile = {build = profileBuild, anim = profileAnim, color={r=0,g=0,b=0}} } )
			shiftPatrols(sim)
			sim:processReactions(unit)
						

			script:queue( { body="Alright everyone, switch to patrol pattern Echo Alpha", instructions="", header=STRINGS.MISSIONS.JAILBREAK.GUARD, type="enemyMessage", 
				profileAnim = profileAnim,
				profileBuild = profileBuild,
			} )
			script:queue( 5*cdefs.SECONDS )
			script:queue( { type="clearEnemyMessage" } )			
		end
	end
end

---------------------------------------------------------------------------------------------
-- Begin!

local incident = class()

function incident:init( scriptMgr, sim )
	self.scriptMgr = scriptMgr
	scriptMgr:addHook( "shift_change", hijackConsole, false )
end

return incident
