local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local inventory = include( "sim/inventory" )
local unitdefs = include( "sim/unitdefs" )
local mission_util = include( "sim/missions/mission_util" )
local simfactory = include( "sim/simfactory" )

---------------------------------------------------------------------------------------------
-- Local helpers

local INCIDENT_NAME = "SAFE ACCESS"

local function isSafe( u )
	return u:getTraits().safeUnit and not u:getTraits().incident_installed
end

local function hook( script, sim )
	local safeUnit = simquery.findUnit( sim:getAllUnits(), isSafe )
	if safeUnit == nil then
		log:write( "safe_sell_contents : no valid safe" )
		return
	end

	local stage = 1

	local option = nil
	while option == nil do
		local currentPlayer = sim:getCurrentPlayer()
		log:write( "safe_sell_contents : unit [%d] at <%d, %d>", safeUnit:getID(), safeUnit:getLocation() )
		safeUnit:getTraits().incident_installed = true
		local _, triggerData = script:waitFor( mission_util.PC_LOOTED_SAFE_PRE( safeUnit:getID() ))

		local unit = triggerData.unit
		
		local stealth = unit:getSkillLevel( "stealth" )
		local anarchy = unit:getSkillLevel( "anarchy" )
		local pronoun = STRINGS.GENDER_CONTEXT[unit:getUnitData().gender].he
		local possesivePronoun = STRINGS.GENDER_CONTEXT[unit:getUnitData().gender].his	

		local item = "item_corpdata_extra"
		
		
		inventory.giftUnit( sim, safeUnit, item )

		local cred = 300		
		if stage == 1 then

		   	local txt = string.format( "As %s starts working on the safe, a rogue signal takes over %s comm.\n\n<c:ffffff>\"What? Who the hell are you? look..I don't really care. But I've got something going with that safe. Back away and I'll make it worth while..\"</>",unit:getName(),possesivePronoun  )
			local options =
		    {	      
		    	"Not worth it, access the safe.",
		        "Accept the credits and move on <c:F4FF78>(gain 300 CREDITS)</>", 
		    }
			option = mission_util.showDialog( sim, INCIDENT_NAME, txt, options, { enemyProfile = {build="portraits/courier_face",anim="portraits/courier_face", color={r=0,g=0,b=0} } } )	 

			if option == 1 then
				mission_util.showBadResult( sim, INCIDENT_NAME, string.format("<c:ffffff>\"Not smart, whoever you are..\"</>.\n\n<c:F4FF78>(Alarm increased by 3)</>") , { enemyProfile = {build="portraits/courier_face",anim="portraits/courier_face", color={r=0,g=0,b=0} } } )	 
				sim:trackerAdvance(3)
			elseif option == 2 then
				mission_util.showGoodResult( sim, INCIDENT_NAME, string.format("<c:ffffff>\"Rare to find someone with class these days\"</>.\n\n<c:F4FF78>(gain 300 CREDITS)</>") , { enemyProfile = {build="portraits/courier_face",anim="portraits/courier_face", color={r=0,g=0,b=0} } } )	 
				currentPlayer:addCredits(300)
				triggerData.abort = true		
				stage = 2			
				option = nil
			end
		elseif stage == 2 then
		   	local txt = string.format( "<c:ffffff>\"Hey, I thought we had a deal?\n\nDon't go and ruin the crush I have on you\"</>")
			local options =
		    {	      
		    	"We need the stuff, take it",
		        "A deal is a deal", 
		    }
			option = mission_util.showDialog( sim, INCIDENT_NAME, txt, options, { enemyProfile = {build="portraits/courier_face",anim="portraits/courier_face", color={r=0,g=0,b=0} } } )	 
			if option == 1 then
				mission_util.showBadResult( sim, INCIDENT_NAME, string.format("<c:ffffff>\"You broke my heart\"</>.\n\n<c:F4FF78>(Alarm increased by 5)</>") , { enemyProfile = {build="portraits/courier_face",anim="portraits/courier_face", color={r=0,g=0,b=0} } } )	 
				sim:trackerAdvance(5)
			elseif option == 2 then
				mission_util.showNeutralResult( sim, INCIDENT_NAME, string.format("<c:ffffff>\"I'll keep my eyes open for you, maybe we can help each other again in the future.\"</>") , { enemyProfile = {build="portraits/courier_face",anim="portraits/courier_face", color={r=0,g=0,b=0} } } )	 		
				triggerData.abort = true		
				option = nil
			end			
		end
	end
end

---------------------------------------------------------------------------------------------
-- Begin!

local incident = class()

function incident:init( scriptMgr, sim )
	self.scriptMgr = scriptMgr
	scriptMgr:addHook( "sell contnets", hook, false )
end

return incident

