local array = include( "modules/array" )
local util = include( "modules/util" )
local mathutil = include( "modules/mathutil" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local inventory = include( "sim/inventory" )
local unitdefs = include( "sim/unitdefs" )
local usable_item = include( "sim/units/usable_item" )
local mission_util = include( "sim/missions/mission_util" )



local incident = class(mission_util.alpha_talk)

local INCIDENT_NAME = "Covert Dialog"

incident.purchase_cost = 500
incident.purchase_list = {
	{"item_dartgun", 1,},
	{"item_clip", 1,},
	{"item_stickycam", 1,},
	{"item_adrenaline", 1,},
	{"item_lockdecoder", 1,},
	{ "item_stim", 1, },
	{ "item_cloakingrig_1", 1, },
	
--	{ "item_dartgun_dam", 1, },
--	{ "item_stim_2", 1, },
--	{ "item_cloakingrig_2", 1, },
--	{ "augment_net_downlink", 1, },
}

function incident:talkHook( script, sim, agent )
	local option
	while option == nil do
		local _, triggerData = script:waitFor( mission_util.PC_TALKED_TO( agent:getID() ))
		local unit = triggerData.sourceUnit
		
		local wlist = util.weighted_list( self.purchase_list )
		local w = sim:nextRand( 1, wlist:getTotalWeight() )
		local item = wlist:getChoice( w )
		
		triggerData.abort = true
		
		local txt = "I have a device that may be of some use to you.  For a price."
		local options =
		{
			string.format( "Purchase.\n<c:F4FF78>(%d credits)</c>", self.purchase_cost ),
			"No Thanks."
		}

		local profileBuild = agent.profile_build	
		local profileAnim = agent.profile_anim

		option = mission_util.showDialog( sim, INCIDENT_NAME, txt, options, { enemyProfile = {build = profileBuild, anim = profileAnim, color={r=0,g=0,b=0}} } )	 

		local credits = unit:getPlayerOwner():getCredits()

		if option == 1 then
			if credits >= self.purchase_cost then
				unit:getPlayerOwner():addCredits( -self.purchase_cost )
				mission_util.giftItem( sim, unit, item )
				sim:warpUnit( agent, nil )
				sim:despawnUnit( agent )
			else
				local hundreds = math.floor(credits/100)
				local anarchyCheck = math.floor(sim:nextRand()*3)+2 - hundreds
				if unit:getSkillLevel( "anarchy" ) >= anarchyCheck then
					local txtApprove = string.format( "Fine, you can have it for %s. But only because I can recognize good fellow when I see one.", credits )
					mission_util.showDialog( sim, "Covert Dialog", txtApprove, nil, { enemyProfile = {build = profileBuild, anim = profileAnim, color={r=0,g=0,b=0}} } )
					unit:getPlayerOwner():addCredits( -credits )
					mission_util.giftItem( sim, unit, item )
					sim:warpUnit( agent, nil )
					sim:despawnUnit( agent )
				else 
					mission_util.showDialog( sim, "Covert Dialog", "Don't try to swindle me. You'll be sorry.", nil, { enemyProfile = {build = profileBuild, anim = profileAnim, color={r=0,g=0,b=0}} } )
					local num = math.floor(sim:nextRand()*3)+1
					if num == 1 then 
						sim:trackerAdvance(1)
					elseif num == 2 then
						sim:dispatchEvent( simdefs.EV_PLAY_SOUND, simdefs.SOUND_HIT_ENERGY_FLESH.path ) 
						unit:setKO( sim, 1)	
					elseif num == 3 then
						unit:getPlayerOwner():addCPUs( -1 )
						sim:dispatchEvent( simdefs.EV_UNIT_FLY_TXT, {txt=util.sformat(STRINGS.UI.FLY_TXT.MINUS_PWR, 1), x=x0,y=y0, color={r=163/255,g=243/255,b=248/255,a=1},} )
					end
					sim:warpUnit( agent, nil )
					sim:despawnUnit( agent )	
				end	
				
			end
		else
			option = nil
		end
	end
end

return incident