----------------------------------------------------------------
-- Copyright (c) 2012 Klei Entertainment Inc.
-- All Rights Reserved.
-- SPY SOCIETY.
----------------------------------------------------------------

local cdefs = include( "client_defs" )
local util = include( "client_util" )
local commondefs = include( "sim/unitdefs/commondefs" )
local commonanims = include("common_anims")


local AGENT_ANIMS = commondefs.AGENT_ANIMS
local GUARD_ANIMS = commondefs.GUARD_ANIMS
local HOSTAGE_ANIMS = commondefs.HOSTAGE_ANIMS
local DRONE_ANIMS = commondefs.DRONE_ANIMS
local FLOAT_DRONE_ANIMS = commondefs.FLOAT_DRONE_ANIMS
local FLOAT_DRONE_TANK_ANIMS = commondefs.FLOAT_DRONE_TANK_ANIMS
local Layer = commondefs.Layer
local BoundType = commondefs.BoundType

-------------------------------------------------------------------
-- Data for anim definitions.

local animdefs =
{

	kanim_cyborg_engineer =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/engineer.abld",
			"data/anims/characters/anims_male/shared_male_robot_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	
			"data/anims/characters/anims_male/tech_basic_a_04.abld", 	 
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_engineer.abld",
		},
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = util.tconcat(
			{"data/anims/characters/anims_male/shared_basic_b_01.adef"},
			commonanims.male.anims_1h,
			commonanims.male.anims,
			commonanims.male.attacks_1h,
			commonanims.male.tech,
			{"data/anims/characters/anims_male/tech_basic_a_03.adef"}),
		anims_2h = util.tconcat(
			{"data/anims/characters/anims_male/shared_basic_b_01.adef"},
			commonanims.male.anims_2h,
			commonanims.male.anims,
			commonanims.male.attacks_1h,
			commonanims.male.attacks_2h,
			commonanims.male.tech,
			{"data/anims/characters/anims_male/tech_basic_a_03.adef"}),
		--anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,	
	},

	kanim_smalgrenade =
	{
			
		build = "data/anims/fx/grenade_scanner.abld",
		anims = { "data/anims/fx/grenade_scanner.adef" },
		symbol = "character",
		shouldFlip = true,
		scale = 0.08,
		layer = Layer.Object,
		boundType = BoundType.bound_1x1_med_med,
		filterSymbols = {{symbol="outline",filter="default"},{symbol="tile_outline",filter="default"},{symbol="teal",filter="default"},{symbol="red",filter="default"},{symbol="Highlight",filter="default"}},
	},	

		kanim_lady_cyberneticist =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 			
			"data/anims/characters/anims_female/shared_female_hits_01.abld",		 
			"data/anims/characters/anims_female/shared_female_attacks_a_01.abld",	
			"data/anims/characters/agents/agent_nu.abld",
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_nu.abld",
		},
		grp_anims = commonanims.female.grp_anims,

		anims = commonanims.female.default_anims_unarmed,
		anims_1h = commonanims.female.default_anims_1h,
		anims_2h = commonanims.female.default_anims_2h,

		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,
	},


	kanim_drone_mod =
	{
		build = 
		{ 
			"data/anims/characters/agents/new_droid.abld",
			--"data/anims/characters/corp_SK/sankaku_droid.abld",	 
		},
		anims =
		{		
			"data/anims/characters/agents/new_droid.adef",
			--"data/anims/characters/corp_SK/sankaku_droid.adef",
		},
		anims_1h =
		{
			"data/anims/characters/agents/new_droid.adef",
			--"data/anims/characters/corp_SK/sankaku_droid.adef",
		},
		anims_2h =
		{	
			"data/anims/characters/agents/new_droid.adef",
			--"data/anims/characters/corp_SK/sankaku_droid.adef",
		},


		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.13,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_closed" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},

		animMap = {
	idle_ko = "idle_closed",
	cover = "idle",
	pin = "idle",

	walk_pre = "move_pre",
	cover_run = "move_pre",
	walk = "move",
	walk180 = "move",
	snk = "move",
	run = "move",
	walk_pst = "move_pst",
	run_pst = "move_pst",
    snk_pst = "move_pst",
	pin_pre = "idle",

	shoot1 = "shoot",
	shoot2 = "shoot",
	shoot3 = "shoot",
	overwatch_pre = "shoot_pre",
	overwatch = "shoot_pre",
    pinshoot_pre = "shoot_pre",
    pinshoot = "shoot",
    pinshoot_pst = "shoot_pst",
    pin_stand = "idle",
	tinker = "shoot_pre",
tinker_loop = "shoot_pre",
tinker_pst = "shoot_pst",

	hitfrt = "hit",
	hitbck = "hit",
	hitfrt_pst = "hit",
	hitbck_pst = "hit",
	cover_pre = "idle",

	ko = "close",
	get_up = "open",
	get_up_pst = "open",
	idle_pre = "idle",
	lean_pre = "close",
	lean = "idle_closed",
	lean_pst = "open",
	hide_pre = "close",
	hide = "idle_closed",
  	hide_pst = "open",

 	use_comp = "shoot",

	hide_peek_pre_L = "open",
	hide_peek_pre_R = "open",
	hide_peek = "idle",
	peek_L = "shoot_pst",
	peek_R = "shoot_pst",
	hide_peek_pst_L = "close",
	hide_peek_pst_R = "close",

door_peek_pre = "shoot_pre",
door_peek_pst = "shoot_pst",
peek_fwrd = "shoot_pre",
peek_bwrd = "shoot_pre",
peek_pst_fwrd = "shoot_pst",
peek_pst_bwrd = "shoot_pst",
lean_peek_pre_R = "open",
lean_peek_pre_L = "open",
lean_peek_R = "idle",
lean_peek_L = "idle",
lean_peek_pst_R = "close",
lean_peek_pst_L = "close",

overwatchcrouch_melee_idle = "idle",
overwatch_melee_pre = "idle",
overwatch_melee = "idle",

hide_throw_L = "shoot_pre",
hide_throw_R = "shoot_pre",
hide_throw_pst_L = "shoot_pst",
hide_throw_pst_R = "shoot_pst",

throw = "shoot_pre",
throw_pst = "shoot_pst",

lean_throw_L = "shoot_pre",
lean_throw_R = "shoot_pre",
lean_throw_pst_L = "shoot_pst",
lean_throw_pst_R = "shoot_pst",

pick_up = "move_pst",
use_door = "shoot_pre",
use_door_pst = "shoot_pst",

hide_reload = "open",
lean_reload = "open",
reload = "shoot_pst",

revive = "shoot_pst",

	shrug = "idle",
},
	},

	kanim_agent_ghuff =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/agent_ghuff.abld",
			"data/anims/characters/anims_male/shared_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	
			"data/anims/characters/anims_male/stealth_basic_a_04.abld",				
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_ghuff.abld",
		},
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = commonanims.male.default_anims_1h,
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},
		peekBranchSet = 1,
	},

	

	kanim_mod_decoy =
	{
		wireframe =
		{
			"data/anims/characters/enemy/ko_flack_overlay_holo.abld",
		},
		build = 
		{ 
			"data/anims/characters/enemy/ko_flack_overlay_holo.abld",
		},
		grp_build = 
		{
			"data/anims/characters/enemy/ko_flack_overlay_holo.abld",
		},		
		grp_anims = commonanims.male.grp_anims,

		anims = util.tconcat(
		  	{ "data/anims/mainframe/suitcase_computer.adef" },
			--commonanims.male.default_anims_panic
			commonanims.male.default_anims_2h ),
		
		anims_1h = util.tconcat(
			{"data/anims/characters/anims_male/shared_basic_b_01.adef"},
			commonanims.male.anims_1h,
			commonanims.male.anims,
			commonanims.male.attacks_1h,
			commonanims.male.tech,
			{"data/anims/characters/anims_male/tech_basic_a_03.adef"}),
		anims_2h = commonanims.male.default_anims_2h,
		animMap = GUARD_ANIMS,
		
		symbol = "character",
		anim = "idle",
		
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.FX,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,
			
	},	

kanim_agent_mist_01 =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			
			"data/anims/characters/anims_female/shared_female_hits_01.abld",		 
			"data/anims/characters/anims_female/shared_female_attacks_a_01.abld",	
			"data/anims/characters/agents/agent_mist.abld",			
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_mist.abld",
		},
		grp_anims = commonanims.female.grp_anims,

		anims = commonanims.female.default_anims_unarmed,
		anims_1h = commonanims.female.default_anims_1h,
		anims_2h = commonanims.female.default_anims_2h,

		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,
	},

}

return animdefs