----------------------------------------------------------------
-- Copyright (c) 2012 Klei Entertainment Inc.
-- All Rights Reserved.
-- SPY SOCIETY.
----------------------------------------------------------------

local cdefs = include( "client_defs" )
local util = include( "client_util" )
local commondefs = include( "sim/unitdefs/commondefs" )
local commonanims = include("common_anims")


local AGENT_ANIMS = commondefs.AGENT_ANIMS
local GUARD_ANIMS = commondefs.GUARD_ANIMS
local HOSTAGE_ANIMS = commondefs.HOSTAGE_ANIMS
local DRONE_ANIMS = commondefs.DRONE_ANIMS
local FLOAT_DRONE_ANIMS = commondefs.FLOAT_DRONE_ANIMS
local FLOAT_DRONE_TANK_ANIMS = commondefs.FLOAT_DRONE_TANK_ANIMS
local Layer = commondefs.Layer
local BoundType = commondefs.BoundType

-----------------------------------------------------------------
-- Data for anim definitions.

local animdefs =
{

---------------------- Removes occupied tile highligts:

kanim_hud_agent_hud =
	{
		build = {  "data/anims/gui/mod_agent_hud.abld",	 },
		anims = {  "data/anims/gui/hud_agent_hud.adef",	 },

		--symbol = "APMeter",
		anim = "default",
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character, -- this doesn't really apply to HUD stuff...
	},

-------------------------------- Main game agents:
	kanim_stealth_male =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/agent_deckard.abld",
			"data/anims/characters/anims_male/shared_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	
			"data/anims/characters/anims_male/stealth_basic_a_04.abld",				
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_deckard.abld",
		},
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = commonanims.male.default_anims_1h,
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},
		peekBranchSet = 1,
	},

	kanim_stealth_male_a =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/agent_deckard2.abld",
			"data/anims/characters/anims_male/shared_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	
			"data/anims/characters/anims_male/stealth_basic_a_04.abld",				
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_deckard2.abld",
		},
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = commonanims.male.default_anims_1h,
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},
		peekBranchSet = 1,
	},

	kanim_hacker_male =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/agent_tony.abld",
			"data/anims/characters/anims_male/shared_hits_01.abld",		 
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_tony.abld",
		},		
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = util.tconcat(
			{"data/anims/characters/anims_male/shared_basic_b_01.adef"},
			commonanims.male.anims_1h,
			commonanims.male.anims,
			commonanims.male.attacks_1h,
			commonanims.male.tech,
			{"data/anims/characters/anims_male/tech_basic_a_03.adef"}),
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,
	},	

	kanim_hacker_male_a =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/agent_tony2.abld",
			"data/anims/characters/anims_male/shared_hits_01.abld",		 
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_tony2.abld",
		},		
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = util.tconcat(
			{"data/anims/characters/anims_male/shared_basic_b_01.adef"},
			commonanims.male.anims_1h,
			commonanims.male.anims,
			commonanims.male.attacks_1h,
			commonanims.male.tech,
			{"data/anims/characters/anims_male/tech_basic_a_03.adef"}),
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,
	},	

	
	kanim_sharpshooter_male =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/agent_shalem.abld",
			"data/anims/characters/anims_male/shared_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	 	 
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_shalem.abld",
		},
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = commonanims.male.default_anims_1h,
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,	
	},

	kanim_sharpshooter_male_a =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/agent_shalem2.abld",
			"data/anims/characters/anims_male/shared_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	 	 
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_shalem2.abld",
		},
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = commonanims.male.default_anims_1h,
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,	
	},


	kanim_female_engineer_2 =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 			
			"data/anims/characters/anims_female/shared_female_hits_01.abld",		 
			"data/anims/characters/anims_female/shared_female_attacks_a_01.abld",	
			"data/anims/characters/agents/agent_international.abld",
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_international.abld",
		},
		grp_anims = commonanims.female.grp_anims,

		anims = commonanims.female.default_anims_unarmed,
		anims_1h = commonanims.female.default_anims_1h,
		anims_2h = commonanims.female.default_anims_2h,

		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet =  2,
	},

	kanim_female_engineer_2_a =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 			
			"data/anims/characters/anims_female/shared_female_hits_01.abld",		 
			"data/anims/characters/anims_female/shared_female_attacks_a_01.abld",		
			"data/anims/characters/agents/agent_international2.abld",			
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_international2.abld",
		},
		grp_anims = commonanims.female.grp_anims,

		anims = commonanims.female.default_anims_unarmed,
		anims_1h = commonanims.female.default_anims_1h,
		anims_2h = commonanims.female.default_anims_2h,

		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet =  2,
	},

	kanim_female_stealth_2 =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 			
			"data/anims/characters/anims_female/shared_female_hits_01.abld",		 
			"data/anims/characters/anims_female/shared_female_attacks_a_01.abld",	
			"data/anims/characters/agents/agent_banks.abld",
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_banks.abld",
		},
		grp_anims = commonanims.female.grp_anims,

		anims = commonanims.female.default_anims_unarmed,
		anims_1h = commonanims.female.default_anims_1h,
		anims_2h = commonanims.female.default_anims_2h,

		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,
	},

	kanim_female_stealth_2_a =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			
			"data/anims/characters/anims_female/shared_female_hits_01.abld",		 
			"data/anims/characters/anims_female/shared_female_attacks_a_01.abld",	
			"data/anims/characters/agents/agent_banks2.abld",			
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_banks.abld",
		},
		grp_anims = commonanims.female.grp_anims,

		anims = commonanims.female.default_anims_unarmed,
		anims_1h = commonanims.female.default_anims_1h,
		anims_2h = commonanims.female.default_anims_2h,

		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,
	},


	kanim_female_sharpshooter_2 =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 			
			"data/anims/characters/anims_female/shared_female_hits_01.abld",		 
			"data/anims/characters/anims_female/shared_female_attacks_a_01.abld",	
			"data/anims/characters/agents/agent_nika.abld",			
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_nika.abld",
		},
		grp_anims = commonanims.female.grp_anims,

		anims = commonanims.female.default_anims_unarmed,
		anims_1h = commonanims.female.default_anims_1h,
		anims_2h = commonanims.female.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,
	},

	kanim_female_sharpshooter_2_a =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 			
			"data/anims/characters/anims_female/shared_female_hits_01.abld",		 
			"data/anims/characters/anims_female/shared_female_attacks_a_01.abld",	
			"data/anims/characters/agents/agent_nika2.abld",			
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_nika.abld",
		},
		grp_anims = commonanims.female.grp_anims,

		anims = commonanims.female.default_anims_unarmed,
		anims_1h = commonanims.female.default_anims_1h,
		anims_2h = commonanims.female.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,
	},

	kanim_cyborg_male =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/agent_sharp.abld",
			"data/anims/characters/anims_male/shared_male_robot_hits_01.abld",	
		--	"data/anims/characters/anims_male/shared_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	 	 
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_sharp.abld",
		},
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = commonanims.male.default_anims_1h,
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,	
	},

	kanim_cyborg_male_a =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/agent_sharp2.abld",
			"data/anims/characters/anims_male/shared_male_robot_hits_01.abld",	
		--	"data/anims/characters/anims_male/shared_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	 	 
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_sharp2.abld",
		},
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = commonanims.male.default_anims_1h,
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,	
	},	

	kanim_disguise_female =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/anims_female/shared_female_hits_01.abld",		 
			"data/anims/characters/anims_female/shared_female_attacks_a_01.abld",	
			"data/anims/characters/agents/agent_prism.abld",
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_prism.abld",
		},
		grp_anims = commonanims.female.grp_anims,

		anims = commonanims.female.default_anims_unarmed,
		anims_1h = commonanims.female.default_anims_1h,
		anims_2h = commonanims.female.default_anims_2h,

		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,
	},

	kanim_disguise_female_a =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/anims_female/shared_female_hits_01.abld",		 
			"data/anims/characters/anims_female/shared_female_attacks_a_01.abld",	
			"data/anims/characters/agents/agent_prism2.abld",
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_prism2.abld",
		},
		grp_anims = commonanims.female.grp_anims,

		anims = commonanims.female.default_anims_unarmed,
		anims_1h = commonanims.female.default_anims_1h,
		anims_2h = commonanims.female.default_anims_2h,

		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},		
		peekBranchSet = 1,
	},

---------------- Monst3r and Central

kanim_monst3r = 
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/agent_monst3r.abld",
			"data/anims/characters/anims_male/shared_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	
			"data/anims/characters/anims_male/stealth_basic_a_04.abld",				
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_monst3r.abld",
		},
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = commonanims.male.default_anims_1h,
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},
		peekBranchSet = 1,	

	},	

	kanim_central = 
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 			
			"data/anims/characters/anims_female/shared_female_hits_01.abld",	
			"data/anims/characters/anims_female/shared_female_attacks_a_01.abld",	
			"data/anims/characters/agents/agent_central.abld",
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_central.abld",
		},
		grp_anims = commonanims.female.grp_anims,
		anims = commonanims.female.default_anims_unarmed,
		anims_1h = commonanims.female.default_anims_1h,
		anims_2h = commonanims.female.default_anims_2h,

		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},
		peekBranchSet = 1,			

	},	


---------------- Prisoner and Courier

kanim_courier_male =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/courier.abld",
			"data/anims/characters/anims_male/shared_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",				
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_courier.abld",
		},		

		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = commonanims.male.default_anims_1h,
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},
		peekBranchSet = 1,
	},

	kanim_prisoner_male =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/prisoner.abld",
			"data/anims/characters/anims_male/shared_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",				
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_prisoner.abld",
		},
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = commonanims.male.default_anims_1h,
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},
		peekBranchSet = 1,
	},	
-----------------------------------------------------------------------

----------- Contingency Plan DLC agents, kanims will give empty space without DLC installed.

	kanim_olivia =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 			
			"data/anims/characters/anims_female/shared_female_hits_01.abld",	
			"data/anims/characters/anims_female/shared_female_attacks_a_01.abld",	
			"data/anims/characters/agents/agent_olivia.abld",
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_olivia.abld",
		},
		grp_anims = commonanims.female.grp_anims,

		anims = commonanims.female.default_anims_unarmed,
		anims_1h = commonanims.female.default_anims_1h,
		anims_2h = commonanims.female.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},
		peekBranchSet = 1,
	},

	kanim_dracul =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/agent_dracul.abld",
			"data/anims/characters/anims_male/shared_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	
			"data/anims/characters/anims_male/stealth_basic_a_04.abld",				
		},
		grp_build = 
		{                                 
			"data/anims/characters/agents/grp_agent_dracul.abld",
		},
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = commonanims.male.default_anims_1h,
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},
		peekBranchSet = 1,
	},

	kanim_rush =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 			
			"data/anims/characters/anims_female/shared_female_hits_01.abld",	
			"data/anims/characters/anims_female/shared_female_attacks_a_01.abld",			
			"data/anims/characters/agents/agent_rush.abld",
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_rush.abld",
		},
		grp_anims = commonanims.female.grp_anims,

		anims = commonanims.female.default_anims_unarmed,
		anims_1h = commonanims.female.default_anims_1h,
		anims_2h = commonanims.female.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},
		peekBranchSet = 1,
	},

	kanim_derek =
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/agent_derek.abld",
			"data/anims/characters/anims_male/shared_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	
			"data/anims/characters/anims_male/stealth_basic_a_04.abld",				
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_derek.abld",
		},
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = commonanims.male.default_anims_1h,
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},
		peekBranchSet = 1,
	},

---------------- Guns:

	kanim_light_revolver =
	{
		wireframe =
		{
			"data/anims/characters/guns/gun_pistol_empty_wire.abld",
		},
		build = "data/anims/characters/guns/gun_pistol_lowbore.abld",		
		grp_build = "data/anims/characters/guns/grp_gun_pistol_lowbore.abld",
		anims = {},
	},
	kanim_light_rifle =
	{
		wireframe =
		{
			"data/anims/characters/guns/gun_pistol_empty_wire.abld",
		},
		build = "data/anims/characters/guns/gun_rifle_lowbore.abld",
		grp_build = "data/anims/characters/guns/grp_gun_rifle_lowbore.abld",
		anims = {},
	},
	kanim_light_smg =
	{
		wireframe =
		{
			"data/anims/characters/guns/gun_pistol_empty_wire.abld",
		},
		build = "data/anims/characters/guns/gun_smg.abld",
		grp_build = "data/anims/characters/guns/grp_gun_smg.abld",
		anims = {},
	},
	kanim_precise_smg =
	{
		wireframe =
		{
			"data/anims/characters/guns/gun_pistol_empty_wire.abld",
		},
		build = "data/anims/characters/guns/gun_smg_precise.abld",
		grp_build = "data/anims/characters/guns/grp_gun_smg_precise.abld",
		anims = {},
	},	

	kanim_precise_revolver =
	{
		wireframe =
		{
			"data/anims/characters/guns/gun_pistol_empty_wire.abld",
		},
		build = "data/anims/characters/guns/gun_pistol_precise.abld",
		grp_build = "data/anims/characters/guns/grp_gun_pistol_precise.abld",
		anims = {},
	},
	kanim_precise_rifle =
	{
		wireframe =
		{
			"data/anims/characters/guns/gun_pistol_empty_wire.abld",
		},
		build = "data/anims/characters/guns/gun_rifle_precise.abld",
		grp_build = "data/anims/characters/guns/grp_gun_rifle_precise.abld",
		anims = {},
	},

------------------------------------------------

kanim_gunpoint_conway =	
	{
		wireframe =
		{
			"data/anims/characters/agents/agent_male_empty.abld",
		},
		build = 
		{ 
			"data/anims/characters/agents/agent_conway.abld",
			"data/anims/characters/anims_male/shared_hits_01.abld",	
			"data/anims/characters/anims_male/shared_attacks_a_01.abld",	
			"data/anims/characters/anims_male/stealth_basic_a_04.abld",				
		},
		grp_build = 
		{
			"data/anims/characters/agents/grp_agent_conway.abld",
		},
		grp_anims = commonanims.male.grp_anims,

		anims = commonanims.male.default_anims_unarmed,
		anims_1h = commonanims.male.default_anims_1h,
		anims_2h = commonanims.male.default_anims_2h,
		animMap = AGENT_ANIMS,

		symbol = "character",
		anim = "idle",
		shouldFlip = true,
		scale = 0.25,
		layer = Layer.Unit,
		boundType = BoundType.Character,
		boundTypeOverrides = {			
			{anim="idle_ko" ,boundType= BoundType.CharacterFloor},
			{anim="dead" ,boundType= BoundType.CharacterFloor},
		},
		peekBranchSet = 1,
	},



------------------------------------------------

}

return animdefs