local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include("sim/simdefs")
local speechdefs = include("sim/speechdefs")
local simquery = include("sim/simquery")
local inventory = include("sim/inventory")
local abilityutil = include( "sim/abilities/abilityutil" )

local breakDoor = 
	{

		name = STRINGS.ABILITIES.BREAK_DOOR,
		

		
		profile_icon = "gui/icons/action_icons/Action_icon_Small/icon-item_sneak_small.png",
	--	profile_icon = "gui/icons/item_icons/items_icon_small/icon-item_generic_leg_small2.png",
		--usesAP = true,
		usesMP = true,		
		cpu_cost = 2,
		--usesCPUs = true,
		alwaysShow = false,
		HUDpriority = 2,
		traits = { pwrCost = 2 },

		pwrCost = 2,
		createToolTip = function( self, sim, unit )
			return abilityutil.formatToolTip(STRINGS.ABILITIES.BREAK_DOOR, STRINGS.AMRE.ABILITIES.BREAK_DOOR_2_DESC, 2)
		end,
		

		canUseAbility = function( self, sim, unit, userUnit, cell, direction)
			if not simquery.isAgent(unit) then
				return false
			end

			if unit:getPlayerOwner() and unit:getPlayerOwner():isPC() and unit:getMP() < 2 then
				return false, string.format(STRINGS.UI.REASON.REQUIRES_AP, 2)
			end
			
			--if unit:getPlayerOwner() and unit:getPlayerOwner():isPC() and unit:getAP() < 1 then
			--	return false, string.format(STRINGS.UI.REASON.ATTACK_USED)
			--end

			--if unit:getPlayerOwner() and unit:getPlayerOwner():isPC() and player:getCpus() < 2 then
		--		return false, string.format(STRINGS.UI.REASON.NOT_ENOUGH_PWR)
		--	end

			if unit:getPlayerOwner():getCpus() < 2 then
				return false, STRINGS.UI.COMBAT_PANEL_NO_PWR, STRINGS.UI.FLY_TXT.NOT_ENOUGH_PWR
			end				

			

			local fromCell = cell or sim:getCell( unit:getLocation() )
			local doorExit = direction and fromCell.exits[direction] or nil

			if not doorExit then
				for dir, exit in pairs(fromCell.exits) do
	                if simquery.isClosedDoor(exit) and not simquery.isSecurityExit(exit) then
	                    doorExit = exit
	                    direction = dir
					end
			 if simquery.isClosedDoor(exit) and simquery.isSecurityExit(exit) then
	                    doorExit = exit
	                    direction = dir
					end
				end
			end

			if not doorExit then
				return false
			end

			--if not simquery.canModifyExit( unit, simdefs.EXITOP_BREAK_DOOR, fromCell, direction) then
			--	return false
			--end

			return abilityutil.checkRequirements( unit, userUnit )
		end,
		
		executeAbility = function( self, sim, unit, userUnit, cell, direction)
			unit:resetAllAiming()

			cell = cell or sim:getCell( unit:getLocation() )
			assert( cell )
			local doorExit = direction and cell.exits[direction] or nil

			if not doorExit then
				for dir, exit in pairs(cell.exits) do
	                if simquery.isClosedDoor(exit) and not simquery.isSecurityExit(exit) then
	                    doorExit, direction = exit, dir
					end
				end
			end
			assert(doorExit)
			assert( simquery.canModifyExit( unit, simdefs.EXITOP_BREAK_DOOR, cell, direction ))
			assert( simquery.canReachDoor( unit, cell, direction ))


			simquery.suggestAgentFacing(userUnit, direction)
			if userUnit:isNPC() then
				sim:emitSpeech(unit, speechdefs.HUNT_BREAKDOOR)
			end
			if not unit:getTraits().noDoorAnim then 
				sim:dispatchEvent( simdefs.EV_UNIT_USEDOOR, { unitID = unit:getID(), facing = direction, exitOp=simdefs.EXITOP_BREAK_DOOR } )	
			end
			sim:getPC():glimpseUnit(sim, unit:getID() )
			sim:startTrackerQueue(true)				
			sim:startDaemonQueue()			
			sim:dispatchEvent( simdefs.EV_KO_GROUP, true )
				

			-- append our rules here, like a Mossbird

			local blocked = false
			local altCell = cell
			local str = unit:getTraits().inventoryMaxSize - 3
			local armorPiercing = unit:countArmorPiercingUpgrades("addArmorPiercingMelee") 
			str = str + armorPiercing
			for i = 1, 3, 1 do
				if not blocked and altCell.exits[direction] then
					altCell = altCell.exits[direction].cell
					for i,targetUnit in ipairs(altCell.units) do
						if simquery.isAgent(targetUnit) and not targetUnit:isKO() and not targetUnit:isDead() then
							local armor = targetUnit:getArmor() 							
							--if unit:hasSkill(inventory, armor) then
							if armor < str then
								-- sim:dispatchEvent(simdefs.EV_UNIT_FLOAT_TXT, {txt=STRINGS.UI.FLY_TXT.DOOR_SLAMMED,x=altCell.x,y=altCell.y,color={r=163/255,g=0,b=0,a=1},alwaysShow=true} )
								local koCount = str - armor								
								if targetUnit:getTraits().canKO then			
									targetUnit:setKO(sim, koCount)									
									--sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, {unit=targetUnit})
								elseif targetUnit:getTraits().isDrone then									
									targetUnit:deactivate(sim)
									targetUnit:processEMP( koCount )								
								end
							else
								blocked = targetUnit								
								sim:dispatchEvent(simdefs.EV_UNIT_FLOAT_TXT, {txt=STRINGS.UI.FLY_TXT.ARMORED,x=altCell.x,y=altCell.y,alwaysShow=true} )															
								sim:dispatchEvent( simdefs.EV_UNIT_HIT, {unit = blocked, result = 0} )
								--if to hunt the door-kicker on guard's turn:
								--blocked:getBrain():getSenses():addInterest(cell.x, cell.y, simdefs.SENSE_HIT, simdefs.REASON_WITNESS, unit)								
								--sim:dispatchEvent( simdefs.EV_KO_GROUP, false )
								sim:triggerEvent(simdefs.TRG_UNIT_HIT, {targetUnit=blocked, sourceUnit=unit, x=cell.x, y=cell.y})
								sim:processReactions(blocked) -- as I prefer immediate reaction
							end
						end
					end
				end
			end			
			sim:modifyExit(cell, direction, simdefs.EXITOP_BREAK_DOOR, unit, false)

			if unit:isValid() and not unit:getTraits().noDoorAnim then
				sim:dispatchEvent( simdefs.EV_UNIT_USEDOOR_PST, { unitID = unit:getID(), facing = direction, exitOp=simdefs.EXITOP_BREAK_DOOR } )
			end
			sim:dispatchEvent( simdefs.EV_KO_GROUP, false )
			sim:startTrackerQueue(false)	
			unit:useMP( 2, sim )	
			local player = sim:getCurrentPlayer()
				local cpu = -2
				player:addCPUs( cpu )		
					
			sim:processDaemonQueue()			
			if unit:isValid() and not unit:getTraits().noDoorAnim and not unit:getTraits().interrupted then
				sim:dispatchEvent( simdefs.EV_UNIT_GUNCHECK, { unit = unit, facing = direction } )
			end

		end,
	}

return breakDoor
