local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local inventory = include("sim/inventory")
local abilityutil = include( "sim/abilities/abilityutil" )
local mathutil = include( "modules/mathutil" )
local unitdefs = include( "sim/unitdefs" )
local simunit = include( "sim/simunit" )
local simfactory = include( "sim/simfactory" )
local modifiers = include( "sim/modifiers" )
local mainframe = include( "sim/mainframe" )
local mainframe_common = include("sim/abilities/mainframe_common")
local DEFAULT_ABILITY = mainframe_common.DEFAULT_ABILITY

function simunit:setPlayerOwner( player )
	if player ~= self._parent then
		if self._parent and self._parent.onUnitRemoved then
			self._parent:onUnitRemoved(self)
		end

		self._parent = player

		if self._parent then
			self._parent:onUnitAdded(self)
		end
	end
end


local mindShade =
{
	name = STRINGS.AMRE.ABILITIES.MIND_SHADE,
	profile_icon = "gui/icons/skills_icons/skills_icon_small/icon-mindShade_small.png",
	--profile_icon = "gui/icons/thought_icons/status_channeling.png",
	usesAction = true,
	cpuCost = 2,
	cpu = 2,
	
	createToolTip = function( self,sim, abilityOwner, abilityUser, targetID )
		local targetUnit = sim:getUnit( targetID )
		local cpu = self.cpu		
		--return util.sformat( STRINGS.AMRE.ABILITIES.MIND_SHADE_DESC, util.toupper( targetUnit:getName() ),1)
		return abilityutil.formatToolTip(STRINGS.AMRE.ABILITIES.MIND_SHADE, util.sformat(STRINGS.AMRE.ABILITIES.MIND_SHADE_DESC, cpu))
	end,
		
	getName = function( self, sim, unit )
		return STRINGS.AMRE.ABILITIES.MIND_SHADE
	end,

	
	onSpawnAbility = function( self, sim )
		sim:addTrigger( simdefs.TRG_START_TURN, self )		
	end, 
	
	
	onTrigger = function( self, sim, evType, evData )
    		DEFAULT_ABILITY.onTrigger( self, sim, evType, evData )
    		local player = sim:getCurrentPlayer()
    		if player:isPC() then
			self.cpu = self.cpuCost
        		for _, unit in pairs(sim:getAllUnits()) do
	                        if unit:getTraits().mindShaded then
	                            	unit:getTraits().hasSight = true
	                		unit:getTraits().hasHearing = true
	                            	unit:getTraits().mindShaded = false
					local x0, y0 = unit:getLocation()
					sim:dispatchEvent( simdefs.EV_PLAY_SOUND, {sound= "SpySociety/Psionics/linkPerson", x=x0,y=y0} )
	                		unit:getTraits().LOSperipheralRange = self.PerLOSRange
	                		unit:getTraits().LOSrange = self.LOSRange
	                		sim:refreshUnitLOS( unit )
	                		sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = unit } )
	            		end
        		end
    		end       
	end,	


  	isTarget = function( self, userUnit, targetUnit )
		if not targetUnit:getTraits().isGuard then
			return false
		end         		

		if targetUnit:getTraits().isDrone then
			return false
		end 
		
		if targetUnit:isKO() or targetUnit:isDead() then
			return false
		end
            	return true
        end,

   	
	acquireTargets = function( self, targets, game, sim, unit, userUnit )
			if not self:canUseAbility( sim, unit, userUnit ) then
				return --nil		
			end
			local units = {}
			local x0, y0 = userUnit:getLocation()
			for _, targetUnit in pairs(sim:getAllUnits()) do
				if self:isTarget( userUnit, targetUnit ) then
					local x1,y1 = targetUnit:getLocation()
					local distance =  mathutil.dist2d( x0, y0, x1, y1 )

					if sim:canUnitSeeUnit( userUnit, targetUnit ) and distance <= 7 then
						table.insert( units, targetUnit )
				end
					
				end
			end 

			return targets.unitTarget( game, units, self, unit, userUnit )
		end,

	
		
	canUseAbility = function( self, sim, unit, userUnit )
		-- has a target in range
		local cell = sim:getCell( userUnit:getLocation() )
		local count = 0
		local cpu = self.cpu		
		--local target = sim:getUnit(target)
		for dir, exit in pairs(cell.exits) do
			local unit = array.findIf( exit.cell.units, function( u ) return self:isTarget( sim, userUnit, u ) end )
			if unit then
				count = count + 1
			end					
		end

		if unit:getAP() < 1 then 
			return false, STRINGS.UI.REASON.ATTACK_USED
		end 
		
		if unit:getPlayerOwner():getCpus() < cpu then 
			return false, STRINGS.UI.REASON.NOT_ENOUGH_PWR
		end 

		if unit:getTraits().cooldown and unit:getTraits().cooldown > 0 then
			return false, util.sformat(STRINGS.UI.REASON.COOLDOWN,unit:getTraits().cooldown)
		end

		if unit:getTraits().usesCharges and unit:getTraits().charges < 1 then
			return false, util.sformat(STRINGS.UI.REASON.CHARGES)
		end	
	
	
		return abilityutil.checkRequirements( unit, userUnit)
	end,

	
	executeAbility = function( self, sim, unit, userUnit, target )
    --local mainframe = include( "sim/mainframe" )
    		local player = unit:getPlayerOwner (self)	
	    	local target = sim:getUnit(target)            
	    	local x0,y0 = userUnit:getLocation()
	    	local x1,y1 = target:getLocation()
	      	local newFacing = simquery.getDirectionFromDelta(x1-x0,y1-y0) 
		local cpu = self.cpu
		local cpuCost = self.cpuCost
    		userUnit:setInvisible(false)
		userUnit:setDisguise(false)
		target:setAiming(false)
		target:getTraits().mindShaded = true
     		target:getTraits().hasSight = false
    		target:getTraits().hasHearing = false
    		self.PerLOSRange = target:getTraits().LOSperipheralRange
    		self.LOSRange = target:getTraits().LOSrange
    		target:getTraits().LOSperipheralRange = 0.5
    		target:getTraits().LOSrange = 0.5
    		sim:refreshUnitLOS( target )
    		userUnit:useAP( sim )    		
    		player:addCPUs( - cpu )    		
    		local x0, y0 = unit:getLocation()
		sim:dispatchEvent( simdefs.EV_PLAY_SOUND, {sound= "SpySociety/Psionics/attack_one", x=x1,y=y1} )
    		sim:dispatchEvent( simdefs.EV_UNIT_FLY_TXT, {txt=util.sformat(STRINGS.UI.FLY_TXT.MINUS_PWR, cpu), x=x0,y=y0,  color={r=216/255,g=37/255,b=19/255,a=1},} )
    		sim:dispatchEvent( simdefs.EV_UNIT_FLY_TXT, {txt=util.sformat(STRINGS.AMRE.UI.MIND_SHADE), x=x1,y=y1,  color={r=182/255,g=163/255,b=245/255,a=1},} )
		self.cpu = cpu + cpuCost
	end,
	

}
return mindShade