local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local mission_util = include( "sim/missions/mission_util" )
local inventory = include( "sim/inventory" )
local weighted_list = include( "modules/weighted_list" )

---------------------------------------------------------------------------------------------
-- Local helpers

local function isConsolePred( u )
	return u:getTraits().mainframe_console and not u:getTraits().console_incident
end

local function isSafePred( u )
	return u:getTraits().safeUnit and not u:getTraits().incident_installed
end

local function hijackConsole( script, sim )


	local consoleUnit = simquery.findUnit( sim:getAllUnits(), isConsolePred )
	local safeUnit = simquery.findUnit( sim:getAllUnits(), isSafePred )

	if consoleUnit == nil or safeUnit == nil then
		log:write( "console_credit_virus: no valid console and safe" )
		return
	end
	
	consoleUnit:getTraits().console_incident = true
	safeUnit:getTraits().incident_installed = true

	local x0, y0 = consoleUnit:getLocation()
	log:write( string.format("console_credit_virus : units [%d] at <%d, %d>, [%d] at <%d, %d>", consoleUnit:getID(), x0, y0, safeUnit:getID(), safeUnit:getLocation()) )
	
	local _, triggerData = script:waitFor( mission_util.PC_HIJACKED( consoleUnit:getID() ))

	local title = "Console"
	local unit = triggerData.sourceUnit
	local hacking = unit:getSkillLevel( "hacking" )
	local currentPlayer = sim:getCurrentPlayer()
	local rand  = sim:nextRand(1,10)
	
	if safeUnit:getTraits().credits == nil then
		safeUnit:getTraits().credits = 0
	end

	if rand + hacking > 8 then
		mission_util.showGoodResult( sim, title, string.format("Accessing the console, %s realizes that a virus was hiding in memory. Before you could find it, it found you – and it also found your agency credit account.\n\nActing fast, %s deflected the hack, pointing the virus to a random corporate account instead.\n\nThe money was electronically desposited into a nearby safe.",unit:getName(), unit:getName() ) )
		safeUnit:getTraits().credits = safeUnit:getTraits().credits + 350	
		sim:dispatchEvent( simdefs.EV_CAM_PAN, { safeUnit:getLocation() } )		
		currentPlayer:glimpseUnit( sim, safeUnit:getID() )
		if safeUnit:getPlayerOwner() == currentPlayer then
		--	sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = safeUnit ,reveal = true} )	
		end
		sim:dispatchEvent( simdefs.EV_UNIT_MAINFRAME_UPDATE, {units={safeUnit:getID()},reveal = true} )
	else
		local credit = currentPlayer:getCredits()
		mission_util.showBadResult( sim, title, string.format("Accessing the console, %s realizes that a virus was hiding in memory. Before you could find it, it found you – and it also found your agency credit account.\n\nThe hack was over before %s could stop it.\n\nThe money was electronically desposited into a nearby safe.",unit:getName(),unit:getName()) )
		currentPlayer:addCredits(-credit)
		safeUnit:getTraits().credits = safeUnit:getTraits().credits + credit		
		sim:dispatchEvent( simdefs.EV_CAM_PAN, { safeUnit:getLocation() } )		
		currentPlayer:glimpseUnit( sim, safeUnit:getID() )
		if safeUnit:getPlayerOwner() == currentPlayer then
		--	sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = safeUnit ,reveal = true} )	
		end	
		sim:dispatchEvent( simdefs.EV_UNIT_MAINFRAME_UPDATE, {units={safeUnit:getID()},reveal = true} )		
	end

end

---------------------------------------------------------------------------------------------
-- Begin!

local incident = class()

function incident:init( scriptMgr, sim )
	self.scriptMgr = scriptMgr
	scriptMgr:addHook( "credit_virus", hijackConsole, false )
end

return incident
